@@ -10,11 +10,11 @@ use fil_actors_runtime::{
     ActorError, BURNT_FUNDS_ACTOR_ADDR, REWARD_ACTOR_ADDR, STORAGE_POWER_ACTOR_ADDR,
     SYSTEM_ACTOR_ADDR,
 };
-use fvm_ipld_encoding::RawBytes;
 use fvm_shared::address::Address;
 use fvm_shared::bigint::bigint_ser::BigIntSer;
 use fvm_shared::clock::ChainEpoch;
 use fvm_shared::econ::TokenAmount;
+use fvm_shared::encoding::RawBytes;
 use fvm_shared::error::ExitCode;
 use fvm_shared::sector::StoragePower;
 use fvm_shared::{METHOD_CONSTRUCTOR, METHOD_SEND};
@@ -40,10 +40,7 @@ mod construction_tests {
         assert_eq!(ChainEpoch::from(0), state.epoch);
         assert_eq!(start_realized_power, state.cumsum_realized);
         assert_eq!(*EPOCH_ZERO_REWARD, state.this_epoch_reward);
-        assert_eq!(
-            &*BASELINE_INITIAL_VALUE - 1,
-            state.this_epoch_baseline_power
-        );
+        assert_eq!(&*BASELINE_INITIAL_VALUE - 1, state.this_epoch_baseline_power);
         assert_eq!(&*BASELINE_INITIAL_VALUE, &state.effective_baseline_power);
     }
 
@@ -76,6 +73,7 @@ mod construction_tests {
 }
 
 mod test_award_block_reward {
+    use fvm_shared::encoding::RawBytes;
     use fvm_shared::error::ExitCode;
     use fvm_shared::sector::StoragePower;
     use fvm_shared::METHOD_SEND;
@@ -89,7 +87,7 @@ mod test_award_block_reward {
         rt.set_balance(TokenAmount::from(9));
         rt.expect_validate_caller_addr(vec![*SYSTEM_ACTOR_ADDR]);
         assert_eq!(
-            ExitCode::USR_ILLEGAL_STATE,
+            ExitCode::ErrIllegalState,
             award_block_reward(
                 &mut rt,
                 *WINNER,
@@ -113,7 +111,7 @@ mod test_award_block_reward {
 
         for (reward, penalty) in &reward_penalty_pairs {
             assert_eq!(
-                ExitCode::USR_ILLEGAL_ARGUMENT,
+                ExitCode::ErrIllegalArgument,
                 award_block_reward(
                     &mut rt,
                     *WINNER,
@@ -181,7 +179,7 @@ mod test_award_block_reward {
             RawBytes::serialize(BigIntSer(&expected_reward)).unwrap(),
             expected_reward,
             RawBytes::default(),
-            ExitCode::OK,
+            ExitCode::Ok,
         );
         rt.expect_send(
             *BURNT_FUNDS_ACTOR_ADDR,
@@ -189,7 +187,7 @@ mod test_award_block_reward {
             RawBytes::default(),
             penalty.clone(),
             RawBytes::default(),
-            ExitCode::OK,
+            ExitCode::Ok,
         );
 
         let params = AwardBlockRewardParams {
@@ -256,7 +254,7 @@ mod test_award_block_reward {
             RawBytes::serialize(BigIntSer(&expected_reward)).unwrap(),
             expected_reward.clone(),
             RawBytes::default(),
-            ExitCode::USR_FORBIDDEN,
+            ExitCode::ErrForbidden,
         );
         rt.expect_send(
             *BURNT_FUNDS_ACTOR_ADDR,
@@ -264,7 +262,7 @@ mod test_award_block_reward {
             RawBytes::default(),
             expected_reward,
             RawBytes::default(),
-            ExitCode::OK,
+            ExitCode::Ok,
         );
 
         let params = AwardBlockRewardParams {
@@ -296,14 +294,8 @@ mod test_this_epoch_reward {
 
         let resp: ThisEpochRewardReturn = this_epoch_reward(&mut rt);
 
-        assert_eq!(
-            state.this_epoch_baseline_power,
-            resp.this_epoch_baseline_power
-        );
-        assert_eq!(
-            state.this_epoch_reward_smoothed,
-            resp.this_epoch_reward_smoothed
-        );
+        assert_eq!(state.this_epoch_baseline_power, resp.this_epoch_baseline_power);
+        assert_eq!(state.this_epoch_reward_smoothed, resp.this_epoch_reward_smoothed);
     }
 }
 
@@ -358,7 +350,7 @@ fn award_block_reward(
         .unwrap(),
         expected_payment.clone(),
         RawBytes::default(),
-        ExitCode::OK,
+        ExitCode::Ok,
     );
 
     if penalty > TokenAmount::from(0) {
@@ -368,17 +360,13 @@ fn award_block_reward(
             RawBytes::default(),
             expected_payment,
             RawBytes::default(),
-            ExitCode::OK,
+            ExitCode::Ok,
         );
     }
 
-    let params = RawBytes::serialize(AwardBlockRewardParams {
-        miner,
-        penalty,
-        gas_reward,
-        win_count,
-    })
-    .unwrap();
+    let params =
+        RawBytes::serialize(AwardBlockRewardParams { miner, penalty, gas_reward, win_count })
+            .unwrap();
 
     let serialized_bytes = rt.call::<RewardActor>(Method::AwardBlockReward as u64, &params)?;
 
@@ -388,9 +376,8 @@ fn award_block_reward(
 
 fn this_epoch_reward(rt: &mut MockRuntime) -> ThisEpochRewardReturn {
     rt.expect_validate_caller_any();
-    let serialized_result = rt
-        .call::<RewardActor>(Method::ThisEpochReward as u64, &RawBytes::default())
-        .unwrap();
+    let serialized_result =
+        rt.call::<RewardActor>(Method::ThisEpochReward as u64, &RawBytes::default()).unwrap();
     let resp: ThisEpochRewardReturn = RawBytes::deserialize(&serialized_result).unwrap();
     rt.verify();
     resp
@@ -401,8 +388,6 @@ fn update_network_kpi(rt: &mut MockRuntime, curr_raw_power: &StoragePower) {
     rt.expect_validate_caller_addr(vec![*STORAGE_POWER_ACTOR_ADDR]);
 
     let params = &RawBytes::serialize(BigIntSer(curr_raw_power)).unwrap();
-    assert!(rt
-        .call::<RewardActor>(Method::UpdateNetworkKPI as u64, params)
-        .is_ok());
+    assert!(rt.call::<RewardActor>(Method::UpdateNetworkKPI as u64, params).is_ok());
     rt.verify();
 }
